import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 部门服务对象基类
 *
 * @export
 * @class SysDepartmentServiceBase
 * @extends {EntityServie}
 */
export default class SysDepartmentServiceBase extends EntityService {

    /**
     * Creates an instance of  SysDepartmentServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  SysDepartmentServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof SysDepartmentServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='sysdepartment';
        this.APPDEKEY = 'deptid';
        this.APPDENAME = 'sysdepartments';
        this.APPDETEXT = 'deptname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/select`,isloading);
        }
            return Http.getInstance().get(`/sysdepartments/${context.sysdepartment}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/sysdepartments`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().put(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/sysdepartments/${context.sysdepartment}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().delete(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}`,isloading);
        }
            return Http.getInstance().delete(`/sysdepartments/${context.sysdepartment}`,isloading);

    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/sysdepartments/${context.sysdepartment}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && true){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/sysdepartments/getdraft`,isloading);
        res.data.sysdepartment = data.sysdepartment;
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/checkkey`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/save`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let sysemployeesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees'),'undefined')){
            sysemployeesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysemployees') as any);
            if(sysemployeesData && sysemployeesData.length && sysemployeesData.length > 0){
                sysemployeesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.userid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysemployees = sysemployeesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_sysemployees',JSON.stringify(res.data.sysemployees));
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysDepartmentServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/sysdepartments/fetchdefault`,tempData,isloading);
    }
}