import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 人员服务对象基类
 *
 * @export
 * @class SysEmployeeServiceBase
 * @extends {EntityServie}
 */
export default class SysEmployeeServiceBase extends EntityService {

    /**
     * Creates an instance of  SysEmployeeServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  SysEmployeeServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof SysEmployeeServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='sysemployee';
        this.APPDEKEY = 'userid';
        this.APPDENAME = 'sysemployees';
        this.APPDETEXT = 'personname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/select`,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}/select`,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().get(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/select`,isloading);
        }
            return Http.getInstance().get(`/sysemployees/${context.sysemployee}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees`,data,isloading);
        }
        if(context.sysorganization && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysemployees`,data,isloading);
        }
        if(context.sysdepartment && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/sysemployees`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/sysemployees`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().put(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,data,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().put(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}`,data,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().put(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/sysemployees/${context.sysemployee}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().delete(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().delete(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}`,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().delete(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,isloading);
        }
            return Http.getInstance().delete(`/sysemployees/${context.sysemployee}`,isloading);

    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}`,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().get(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/sysemployees/${context.sysemployee}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && true){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/getdraft`,isloading);
        }
        if(context.sysorganization && true){
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysemployees/getdraft`,isloading);
        }
        if(context.sysdepartment && true){
            return Http.getInstance().get(`/sysdepartments/${context.sysdepartment}/sysemployees/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/sysemployees/getdraft`,isloading);
        res.data.sysemployee = data.sysemployee;
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/checkkey`,data,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}/checkkey`,data,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/sysemployees/${context.sysemployee}/checkkey`,data,isloading);
    }

    /**
     * InitPwd接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async InitPwd(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/initpwd`,data,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}/initpwd`,data,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/initpwd`,data,isloading);
        }
            return Http.getInstance().post(`/sysemployees/${context.sysemployee}/initpwd`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/save`,data,isloading);
        }
        if(context.sysorganization && context.sysemployee){
            return Http.getInstance().post(`/sysorganizations/${context.sysorganization}/sysemployees/${context.sysemployee}/save`,data,isloading);
        }
        if(context.sysdepartment && context.sysemployee){
            return Http.getInstance().post(`/sysdepartments/${context.sysdepartment}/sysemployees/${context.sysemployee}/save`,data,isloading);
        }
        let masterData:any = {};
        let sysdeptmembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers'),'undefined')){
            sysdeptmembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_sysdeptmembers') as any);
            if(sysdeptmembersData && sysdeptmembersData.length && sysdeptmembersData.length > 0){
                sysdeptmembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.memberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.sysdeptmembers = sysdeptmembersData;
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/sysemployees/${context.sysemployee}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_sysdeptmembers',JSON.stringify(res.data.sysdeptmembers));
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysEmployeeServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.sysorganization && context.sysdepartment && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysdepartments/${context.sysdepartment}/sysemployees/fetchdefault`,tempData,isloading);
        }
        if(context.sysorganization && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/sysorganizations/${context.sysorganization}/sysemployees/fetchdefault`,tempData,isloading);
        }
        if(context.sysdepartment && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/sysdepartments/${context.sysdepartment}/sysemployees/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/sysemployees/fetchdefault`,tempData,isloading);
    }
}