import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 组服务对象基类
 *
 * @export
 * @class SysTeamServiceBase
 * @extends {EntityServie}
 */
export default class SysTeamServiceBase extends EntityService {

    /**
     * Creates an instance of  SysTeamServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  SysTeamServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof SysTeamServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='systeam';
        this.APPDEKEY = 'teamid';
        this.APPDENAME = 'systeams';
        this.APPDETEXT = 'teamname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/systeams/${context.systeam}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/systeams`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/systeams/${context.systeam}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/systeams/${context.systeam}`,isloading);

    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/systeams/${context.systeam}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/systeams/getdraft`,isloading);
        res.data.systeam = data.systeam;
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/systeams/${context.systeam}/checkkey`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let systeammembersData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers'),'undefined')){
            systeammembersData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_systeammembers') as any);
            if(systeammembersData && systeammembersData.length && systeammembersData.length > 0){
                systeammembersData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.teammemberid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.systeammembers = systeammembersData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/systeams/${context.systeam}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_systeammembers',JSON.stringify(res.data.systeammembers));
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof SysTeamServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/systeams/fetchdefault`,tempData,isloading);
    }
}